@@ -27,6 +27,24 @@
 #' In another example, all Elsevier URLs at time of writing are have
 #' `http` scheme, while those don't actually work, so we have a
 #' custom fix in this function for that publisher. Anyway, expect changes...
+#' 
+#' @section Register for the Polite Pool:
+#' The `crm_links()` uses the 
+#' [Crossref API](https://github.com/CrossRef/rest-api-doc)
+#' You should send your email address with your `crm_links()` requests. This
+#' has the advantage that queries are placed in the polite pool of servers.
+#' In addition, even if the non-polite pool is having server problems, 
+#' the polite pool is often okay. Including your email address is good practice
+#' as described in the Crossref documentation under 
+#' [Good manners](https://github.com/CrossRef/rest-api-doc).
+#' To pass your email address to Crossref, simply store it as an environment 
+#' variable in .Renviron file like `crossref_email=name@example.com`, or 
+#' `CROSSREF_EMAIL=name@example.com`. 
+#' Save the file and restart your R session. To stop sharing your email when
+#' using rcrossref simply delete it from your `.Renviron` file OR to temporarily
+#' not use your email unset it for the session
+#' like `Sys.unsetenv('crossref_email')`. To be sure your in the polite pool
+#' use curl verbose by e.g., `crm_links(doi = "10.5555/515151", verbose = TRUE)`
 #'
 #' @return `NULL` if no full text links given; a list of tdmurl objects if
 #' links found. a tdmurl object is an S3 class wrapped around a simple list, 
@@ -95,7 +113,7 @@ crm_links <- function(doi, type = 'all', ...) {
 
       if (basename(res$member) == "78") {
         withtype <- lapply(withtype, function(z) {
-          z$URL <- sub("http", "https", z$URL)
+          z$URL <- sub("http://", "https://", z$URL)
           z
         })
       }
